@@ -3,7 +3,7 @@ package Syntax::Keyword::Junction;
 use strict;
 use warnings;
 
-our $VERSION = '0.003006'; # VERSION
+our $VERSION = '0.003007'; # VERSION
 
 # ABSTRACT: Perl6 style Junction operators in Perl5
 
@@ -38,7 +38,7 @@ Syntax::Keyword::Junction - Perl6 style Junction operators in Perl5
 
 =head1 VERSION
 
-version 0.003006
+version 0.003007
 
 =head1 SYNOPSIS
 
@@ -172,7 +172,7 @@ want to export them.
 
 When comparing against a regular expression, you must remember to use a
 regular expression object: C<qr/\d/> B<Not> C</d/>. You must also use either
-C<==> or C<!=>. This is because C<=~> and C<!~> cannot be overriden.
+C<==> or C<!=>. This is because C<=~> and C<!~> cannot be overridden.
 
 =head1 TO DO
 
@@ -191,7 +191,7 @@ incendiary name containing Perl6.
 L<Quantum::Superpositions> provides the same functionality as this, and
 more. However, this module provides this limited functionality at a much
 greater runtime speed, with my benchmarks showing between 500% and 6000%
-improvment.
+improvement.
 
 L<http://dev.perl.org/perl6/doc/design/exe/E06.html> - "The Wonderful World
 of Junctions".
